/* This file is auto-generated from "geldkarte_values.xml" by the typemaker
   tool of Gwenhywfar. 
   Do not edit this file -- all changes will be lost! */
#ifndef GELDKARTE_VALUES_H
#define GELDKARTE_VALUES_H

/** @page P_LC_GELDKARTE_VALUES_PUBLIC LC_GeldKarte_Values (public)
This page describes the properties of LC_GELDKARTE_VALUES
@anchor LC_GELDKARTE_VALUES_Loaded
<h3>Loaded</h3>
<p>
</p>
<p>
Set this property with @ref LC_GeldKarte_Values_SetLoaded, 
get it with @ref LC_GeldKarte_Values_GetLoaded
</p>

@anchor LC_GELDKARTE_VALUES_MaxLoad
<h3>MaxLoad</h3>
<p>
</p>
<p>
Set this property with @ref LC_GeldKarte_Values_SetMaxLoad, 
get it with @ref LC_GeldKarte_Values_GetMaxLoad
</p>

@anchor LC_GELDKARTE_VALUES_MaxXfer
<h3>MaxXfer</h3>
<p>
</p>
<p>
Set this property with @ref LC_GeldKarte_Values_SetMaxXfer, 
get it with @ref LC_GeldKarte_Values_GetMaxXfer
</p>

*/
#ifdef __cplusplus
extern "C" {
#endif

typedef struct LC_GELDKARTE_VALUES LC_GELDKARTE_VALUES;

#ifdef __cplusplus
} /* __cplusplus */
#endif

#include <gwenhywfar/db.h>
#include <gwenhywfar/list2.h>
/* headers */
#include <gwenhywfar/types.h>
#include <gwenhywfar/gwentime.h>
#include <chipcard/chipcard.h>

#ifdef __cplusplus
extern "C" {
#endif


GWEN_LIST2_FUNCTION_LIB_DEFS(LC_GELDKARTE_VALUES, LC_GeldKarte_Values, CHIPCARD_API)

/** Destroys all objects stored in the given LIST2 and the list itself
*/
CHIPCARD_API void LC_GeldKarte_Values_List2_freeAll(LC_GELDKARTE_VALUES_LIST2 *stl);

/** Creates a new object.
*/
CHIPCARD_API LC_GELDKARTE_VALUES *LC_GeldKarte_Values_new();
/** Creates an object from the data in the given GWEN_DB_NODE
*/
CHIPCARD_API LC_GELDKARTE_VALUES *LC_GeldKarte_Values_fromDb(GWEN_DB_NODE *db);
/** Creates and returns a deep copy of thegiven object.
*/
CHIPCARD_API LC_GELDKARTE_VALUES *LC_GeldKarte_Values_dup(const LC_GELDKARTE_VALUES*st);
/** Destroys the given object.
*/
CHIPCARD_API void LC_GeldKarte_Values_free(LC_GELDKARTE_VALUES *st);
/** Increments the usage counter of the given object, so an additional free() is needed to destroy the object.
*/
CHIPCARD_API void LC_GeldKarte_Values_Attach(LC_GELDKARTE_VALUES *st);
/** Reads data from a GWEN_DB.
*/
CHIPCARD_API int LC_GeldKarte_Values_ReadDb(LC_GELDKARTE_VALUES *st, GWEN_DB_NODE *db);
/** Stores an object in the given GWEN_DB_NODE
*/
CHIPCARD_API int LC_GeldKarte_Values_toDb(const LC_GELDKARTE_VALUES*st, GWEN_DB_NODE *db);
/** Returns 0 if this object has not been modified, !=0 otherwise
*/
CHIPCARD_API int LC_GeldKarte_Values_IsModified(const LC_GELDKARTE_VALUES *st);
/** Sets the modified state of the given object
*/
CHIPCARD_API void LC_GeldKarte_Values_SetModified(LC_GELDKARTE_VALUES *st, int i);

/**
* Returns the property @ref LC_GELDKARTE_VALUES_Loaded
*/
CHIPCARD_API int LC_GeldKarte_Values_GetLoaded(const LC_GELDKARTE_VALUES *el);
/**
* Set the property @ref LC_GELDKARTE_VALUES_Loaded
*/
CHIPCARD_API void LC_GeldKarte_Values_SetLoaded(LC_GELDKARTE_VALUES *el, int d);

/**
* Returns the property @ref LC_GELDKARTE_VALUES_MaxLoad
*/
CHIPCARD_API int LC_GeldKarte_Values_GetMaxLoad(const LC_GELDKARTE_VALUES *el);
/**
* Set the property @ref LC_GELDKARTE_VALUES_MaxLoad
*/
CHIPCARD_API void LC_GeldKarte_Values_SetMaxLoad(LC_GELDKARTE_VALUES *el, int d);

/**
* Returns the property @ref LC_GELDKARTE_VALUES_MaxXfer
*/
CHIPCARD_API int LC_GeldKarte_Values_GetMaxXfer(const LC_GELDKARTE_VALUES *el);
/**
* Set the property @ref LC_GELDKARTE_VALUES_MaxXfer
*/
CHIPCARD_API void LC_GeldKarte_Values_SetMaxXfer(LC_GELDKARTE_VALUES *el, int d);


#ifdef __cplusplus
} /* __cplusplus */
#endif


#endif /* GELDKARTE_VALUES_H */
