( cd usr/lib ; rm -rf libchipcardd.so.0 )
( cd usr/lib ; ln -sf libchipcardd.so.0.0.0 libchipcardd.so.0 )
( cd usr/lib ; rm -rf libchipcard_ctapi.so.0 )
( cd usr/lib ; ln -sf libchipcard_ctapi.so.0.0.0 libchipcard_ctapi.so.0 )
( cd usr/lib ; rm -rf libchipcardc.so )
( cd usr/lib ; ln -sf libchipcardc.so.2.2.3 libchipcardc.so )
( cd usr/lib ; rm -rf libchipcardd.so )
( cd usr/lib ; ln -sf libchipcardd.so.0.0.0 libchipcardd.so )
( cd usr/lib ; rm -rf libchipcardc.so.2 )
( cd usr/lib ; ln -sf libchipcardc.so.2.2.3 libchipcardc.so.2 )
( cd usr/lib ; rm -rf libchipcard_ctapi.so )
( cd usr/lib ; ln -sf libchipcard_ctapi.so.0.0.0 libchipcard_ctapi.so )
