/* This file is auto-generated from "hiinsurancedata.xml" by the typemaker
   tool of Gwenhywfar. 
   Do not edit this file -- all changes will be lost! */
#ifndef HIINSURANCEDATA_H
#define HIINSURANCEDATA_H

/** @page P_LC_HI_INSURANCE_DATA_PUBLIC LC_HIInsuranceData (public)
This page describes the properties of LC_HI_INSURANCE_DATA
@anchor LC_HI_INSURANCE_DATA_InstitutionId
<h3>InstitutionId</h3>
<p>
</p>
<p>
Set this property with @ref LC_HIInsuranceData_SetInstitutionId, 
get it with @ref LC_HIInsuranceData_GetInstitutionId
</p>

@anchor LC_HI_INSURANCE_DATA_InstitutionName
<h3>InstitutionName</h3>
<p>
</p>
<p>
Set this property with @ref LC_HIInsuranceData_SetInstitutionName, 
get it with @ref LC_HIInsuranceData_GetInstitutionName
</p>

@anchor LC_HI_INSURANCE_DATA_CoverBegin
<h3>CoverBegin</h3>
<p>
</p>
<p>
Set this property with @ref LC_HIInsuranceData_SetCoverBegin, 
get it with @ref LC_HIInsuranceData_GetCoverBegin
</p>

@anchor LC_HI_INSURANCE_DATA_CoverEnd
<h3>CoverEnd</h3>
<p>
</p>
<p>
Set this property with @ref LC_HIInsuranceData_SetCoverEnd, 
get it with @ref LC_HIInsuranceData_GetCoverEnd
</p>

@anchor LC_HI_INSURANCE_DATA_Status
<h3>Status</h3>
<p>
1: selbstversichert
</p>
<p>
Set this property with @ref LC_HIInsuranceData_SetStatus, 
get it with @ref LC_HIInsuranceData_GetStatus
</p>

@anchor LC_HI_INSURANCE_DATA_Group
<h3>Group</h3>
<p>
'1': x="west"; break; '9': x="ost"; break; '6': x="BVG"; break; '7': x="SVA, nach Aufwand, dt.-nl Grenzgaenger"; break; '8': x="SVA, pauschal"; break; 'M': x="DMP Diabetes mellitus Typ 2, west"; break; 'X': x="DMP Diabetes mellitus Typ 2, ost"; break; 'A': x="DMP Brustkrebs, west"; break; 'C': x="DMP Brustkrebs, ost"; break; 'K': x="DMP KHK, west"; break; 'L': x="DMP KHK, ost"; break; '4': x="nichtversicherter Sozialhilfe-Empfaenger"; break; 'E': x="DMP Diabetes mellitus Typ 1, west"; break; 'N': x="DMP Diabetes mellitus Typ 1, ost"; break; 'D': x="DMP Asthma bronchiale, west"; break; 'F': x="DMP Asthma bronchiale, ost"; break; 'S': x="DMP COPD, west"; break; 'P': x="DMP COPD, ost"; break;
</p>
<p>
Set this property with @ref LC_HIInsuranceData_SetGroup, 
get it with @ref LC_HIInsuranceData_GetGroup
</p>

*/
#ifdef __cplusplus
extern "C" {
#endif

typedef struct LC_HI_INSURANCE_DATA LC_HI_INSURANCE_DATA;

#ifdef __cplusplus
} /* __cplusplus */
#endif

#include <gwenhywfar/db.h>
/* headers */
#include <chipcard/chipcard.h>
#include <gwenhywfar/gwentime.h>

#ifdef __cplusplus
extern "C" {
#endif


/** Creates a new object.
*/
CHIPCARD_API LC_HI_INSURANCE_DATA *LC_HIInsuranceData_new();
/** Creates an object from the data in the given GWEN_DB_NODE
*/
CHIPCARD_API LC_HI_INSURANCE_DATA *LC_HIInsuranceData_fromDb(GWEN_DB_NODE *db);
/** Creates and returns a deep copy of thegiven object.
*/
CHIPCARD_API LC_HI_INSURANCE_DATA *LC_HIInsuranceData_dup(const LC_HI_INSURANCE_DATA*st);
/** Destroys the given object.
*/
CHIPCARD_API void LC_HIInsuranceData_free(LC_HI_INSURANCE_DATA *st);
/** Increments the usage counter of the given object, so an additional free() is needed to destroy the object.
*/
CHIPCARD_API void LC_HIInsuranceData_Attach(LC_HI_INSURANCE_DATA *st);
/** Reads data from a GWEN_DB.
*/
CHIPCARD_API int LC_HIInsuranceData_ReadDb(LC_HI_INSURANCE_DATA *st, GWEN_DB_NODE *db);
/** Stores an object in the given GWEN_DB_NODE
*/
CHIPCARD_API int LC_HIInsuranceData_toDb(const LC_HI_INSURANCE_DATA*st, GWEN_DB_NODE *db);
/** Returns 0 if this object has not been modified, !=0 otherwise
*/
CHIPCARD_API int LC_HIInsuranceData_IsModified(const LC_HI_INSURANCE_DATA *st);
/** Sets the modified state of the given object
*/
CHIPCARD_API void LC_HIInsuranceData_SetModified(LC_HI_INSURANCE_DATA *st, int i);

/**
* Returns the property @ref LC_HI_INSURANCE_DATA_InstitutionId
*/
CHIPCARD_API const char *LC_HIInsuranceData_GetInstitutionId(const LC_HI_INSURANCE_DATA *el);
/**
* Set the property @ref LC_HI_INSURANCE_DATA_InstitutionId
*/
CHIPCARD_API void LC_HIInsuranceData_SetInstitutionId(LC_HI_INSURANCE_DATA *el, const char *d);

/**
* Returns the property @ref LC_HI_INSURANCE_DATA_InstitutionName
*/
CHIPCARD_API const char *LC_HIInsuranceData_GetInstitutionName(const LC_HI_INSURANCE_DATA *el);
/**
* Set the property @ref LC_HI_INSURANCE_DATA_InstitutionName
*/
CHIPCARD_API void LC_HIInsuranceData_SetInstitutionName(LC_HI_INSURANCE_DATA *el, const char *d);

/**
* Returns the property @ref LC_HI_INSURANCE_DATA_CoverBegin
*/
CHIPCARD_API const GWEN_TIME *LC_HIInsuranceData_GetCoverBegin(const LC_HI_INSURANCE_DATA *el);
/**
* Set the property @ref LC_HI_INSURANCE_DATA_CoverBegin
*/
CHIPCARD_API void LC_HIInsuranceData_SetCoverBegin(LC_HI_INSURANCE_DATA *el, const GWEN_TIME *d);

/**
* Returns the property @ref LC_HI_INSURANCE_DATA_CoverEnd
*/
CHIPCARD_API const GWEN_TIME *LC_HIInsuranceData_GetCoverEnd(const LC_HI_INSURANCE_DATA *el);
/**
* Set the property @ref LC_HI_INSURANCE_DATA_CoverEnd
*/
CHIPCARD_API void LC_HIInsuranceData_SetCoverEnd(LC_HI_INSURANCE_DATA *el, const GWEN_TIME *d);

/**
* Returns the property @ref LC_HI_INSURANCE_DATA_Status
*/
CHIPCARD_API const char *LC_HIInsuranceData_GetStatus(const LC_HI_INSURANCE_DATA *el);
/**
* Set the property @ref LC_HI_INSURANCE_DATA_Status
*/
CHIPCARD_API void LC_HIInsuranceData_SetStatus(LC_HI_INSURANCE_DATA *el, const char *d);

/**
* Returns the property @ref LC_HI_INSURANCE_DATA_Group
*/
CHIPCARD_API const char *LC_HIInsuranceData_GetGroup(const LC_HI_INSURANCE_DATA *el);
/**
* Set the property @ref LC_HI_INSURANCE_DATA_Group
*/
CHIPCARD_API void LC_HIInsuranceData_SetGroup(LC_HI_INSURANCE_DATA *el, const char *d);


#ifdef __cplusplus
} /* __cplusplus */
#endif


#endif /* HIINSURANCEDATA_H */
