/* This file is auto-generated from "geldkarte_llog.xml" by the typemaker
   tool of Gwenhywfar. 
   Do not edit this file -- all changes will be lost! */
#ifndef GELDKARTE_LLOG_H
#define GELDKARTE_LLOG_H

/** @page P_LC_GELDKARTE_LLOG_PUBLIC LC_GeldKarte_LLog (public)
This page describes the properties of LC_GELDKARTE_LLOG
@anchor LC_GELDKARTE_LLOG_Status
<h3>Status</h3>
<p>
</p>
<p>
Set this property with @ref LC_GeldKarte_LLog_SetStatus, 
get it with @ref LC_GeldKarte_LLog_GetStatus
</p>

@anchor LC_GELDKARTE_LLOG_BSeq
<h3>BSeq</h3>
<p>
</p>
<p>
Set this property with @ref LC_GeldKarte_LLog_SetBSeq, 
get it with @ref LC_GeldKarte_LLog_GetBSeq
</p>

@anchor LC_GELDKARTE_LLOG_LSeq
<h3>LSeq</h3>
<p>
</p>
<p>
Set this property with @ref LC_GeldKarte_LLog_SetLSeq, 
get it with @ref LC_GeldKarte_LLog_GetLSeq
</p>

@anchor LC_GELDKARTE_LLOG_Value
<h3>Value</h3>
<p>
</p>
<p>
Set this property with @ref LC_GeldKarte_LLog_SetValue, 
get it with @ref LC_GeldKarte_LLog_GetValue
</p>

@anchor LC_GELDKARTE_LLOG_CenterId
<h3>CenterId</h3>
<p>
</p>
<p>
Set this property with @ref LC_GeldKarte_LLog_SetCenterId, 
get it with @ref LC_GeldKarte_LLog_GetCenterId
</p>

@anchor LC_GELDKARTE_LLOG_TerminalId
<h3>TerminalId</h3>
<p>
</p>
<p>
Set this property with @ref LC_GeldKarte_LLog_SetTerminalId, 
get it with @ref LC_GeldKarte_LLog_GetTerminalId
</p>

@anchor LC_GELDKARTE_LLOG_TraceId
<h3>TraceId</h3>
<p>
</p>
<p>
Set this property with @ref LC_GeldKarte_LLog_SetTraceId, 
get it with @ref LC_GeldKarte_LLog_GetTraceId
</p>

@anchor LC_GELDKARTE_LLOG_Loaded
<h3>Loaded</h3>
<p>
</p>
<p>
Set this property with @ref LC_GeldKarte_LLog_SetLoaded, 
get it with @ref LC_GeldKarte_LLog_GetLoaded
</p>

@anchor LC_GELDKARTE_LLOG_Time
<h3>Time</h3>
<p>
</p>
<p>
Set this property with @ref LC_GeldKarte_LLog_SetTime, 
get it with @ref LC_GeldKarte_LLog_GetTime
</p>

*/
#ifdef __cplusplus
extern "C" {
#endif

typedef struct LC_GELDKARTE_LLOG LC_GELDKARTE_LLOG;

#ifdef __cplusplus
} /* __cplusplus */
#endif

#include <gwenhywfar/db.h>
#include <gwenhywfar/list2.h>
/* headers */
#include <gwenhywfar/types.h>
#include <gwenhywfar/gwentime.h>
#include <chipcard/chipcard.h>

#ifdef __cplusplus
extern "C" {
#endif


GWEN_LIST2_FUNCTION_LIB_DEFS(LC_GELDKARTE_LLOG, LC_GeldKarte_LLog, CHIPCARD_API)

/** Destroys all objects stored in the given LIST2 and the list itself
*/
CHIPCARD_API void LC_GeldKarte_LLog_List2_freeAll(LC_GELDKARTE_LLOG_LIST2 *stl);

/** Creates a new object.
*/
CHIPCARD_API LC_GELDKARTE_LLOG *LC_GeldKarte_LLog_new();
/** Creates an object from the data in the given GWEN_DB_NODE
*/
CHIPCARD_API LC_GELDKARTE_LLOG *LC_GeldKarte_LLog_fromDb(GWEN_DB_NODE *db);
/** Creates and returns a deep copy of thegiven object.
*/
CHIPCARD_API LC_GELDKARTE_LLOG *LC_GeldKarte_LLog_dup(const LC_GELDKARTE_LLOG*st);
/** Destroys the given object.
*/
CHIPCARD_API void LC_GeldKarte_LLog_free(LC_GELDKARTE_LLOG *st);
/** Increments the usage counter of the given object, so an additional free() is needed to destroy the object.
*/
CHIPCARD_API void LC_GeldKarte_LLog_Attach(LC_GELDKARTE_LLOG *st);
/** Reads data from a GWEN_DB.
*/
CHIPCARD_API int LC_GeldKarte_LLog_ReadDb(LC_GELDKARTE_LLOG *st, GWEN_DB_NODE *db);
/** Stores an object in the given GWEN_DB_NODE
*/
CHIPCARD_API int LC_GeldKarte_LLog_toDb(const LC_GELDKARTE_LLOG*st, GWEN_DB_NODE *db);
/** Returns 0 if this object has not been modified, !=0 otherwise
*/
CHIPCARD_API int LC_GeldKarte_LLog_IsModified(const LC_GELDKARTE_LLOG *st);
/** Sets the modified state of the given object
*/
CHIPCARD_API void LC_GeldKarte_LLog_SetModified(LC_GELDKARTE_LLOG *st, int i);

/**
* Returns the property @ref LC_GELDKARTE_LLOG_Status
*/
CHIPCARD_API int LC_GeldKarte_LLog_GetStatus(const LC_GELDKARTE_LLOG *el);
/**
* Set the property @ref LC_GELDKARTE_LLOG_Status
*/
CHIPCARD_API void LC_GeldKarte_LLog_SetStatus(LC_GELDKARTE_LLOG *el, int d);

/**
* Returns the property @ref LC_GELDKARTE_LLOG_BSeq
*/
CHIPCARD_API int LC_GeldKarte_LLog_GetBSeq(const LC_GELDKARTE_LLOG *el);
/**
* Set the property @ref LC_GELDKARTE_LLOG_BSeq
*/
CHIPCARD_API void LC_GeldKarte_LLog_SetBSeq(LC_GELDKARTE_LLOG *el, int d);

/**
* Returns the property @ref LC_GELDKARTE_LLOG_LSeq
*/
CHIPCARD_API int LC_GeldKarte_LLog_GetLSeq(const LC_GELDKARTE_LLOG *el);
/**
* Set the property @ref LC_GELDKARTE_LLOG_LSeq
*/
CHIPCARD_API void LC_GeldKarte_LLog_SetLSeq(LC_GELDKARTE_LLOG *el, int d);

/**
* Returns the property @ref LC_GELDKARTE_LLOG_Value
*/
CHIPCARD_API int LC_GeldKarte_LLog_GetValue(const LC_GELDKARTE_LLOG *el);
/**
* Set the property @ref LC_GELDKARTE_LLOG_Value
*/
CHIPCARD_API void LC_GeldKarte_LLog_SetValue(LC_GELDKARTE_LLOG *el, int d);

/**
* Returns the property @ref LC_GELDKARTE_LLOG_CenterId
*/
CHIPCARD_API const char *LC_GeldKarte_LLog_GetCenterId(const LC_GELDKARTE_LLOG *el);
/**
* Set the property @ref LC_GELDKARTE_LLOG_CenterId
*/
CHIPCARD_API void LC_GeldKarte_LLog_SetCenterId(LC_GELDKARTE_LLOG *el, const char *d);

/**
* Returns the property @ref LC_GELDKARTE_LLOG_TerminalId
*/
CHIPCARD_API const char *LC_GeldKarte_LLog_GetTerminalId(const LC_GELDKARTE_LLOG *el);
/**
* Set the property @ref LC_GELDKARTE_LLOG_TerminalId
*/
CHIPCARD_API void LC_GeldKarte_LLog_SetTerminalId(LC_GELDKARTE_LLOG *el, const char *d);

/**
* Returns the property @ref LC_GELDKARTE_LLOG_TraceId
*/
CHIPCARD_API const char *LC_GeldKarte_LLog_GetTraceId(const LC_GELDKARTE_LLOG *el);
/**
* Set the property @ref LC_GELDKARTE_LLOG_TraceId
*/
CHIPCARD_API void LC_GeldKarte_LLog_SetTraceId(LC_GELDKARTE_LLOG *el, const char *d);

/**
* Returns the property @ref LC_GELDKARTE_LLOG_Loaded
*/
CHIPCARD_API int LC_GeldKarte_LLog_GetLoaded(const LC_GELDKARTE_LLOG *el);
/**
* Set the property @ref LC_GELDKARTE_LLOG_Loaded
*/
CHIPCARD_API void LC_GeldKarte_LLog_SetLoaded(LC_GELDKARTE_LLOG *el, int d);

/**
* Returns the property @ref LC_GELDKARTE_LLOG_Time
*/
CHIPCARD_API const GWEN_TIME *LC_GeldKarte_LLog_GetTime(const LC_GELDKARTE_LLOG *el);
/**
* Set the property @ref LC_GELDKARTE_LLOG_Time
*/
CHIPCARD_API void LC_GeldKarte_LLog_SetTime(LC_GELDKARTE_LLOG *el, const GWEN_TIME *d);


#ifdef __cplusplus
} /* __cplusplus */
#endif


#endif /* GELDKARTE_LLOG_H */
